[<img src="https://travis-ci.com/LevyvoNet/gym-mapf.svg?branch=master">](https://travis-ci.com/LevyvoNet/gym-mapf)
[<img src="https://img.shields.io/pypi/pyversions/gym-mapf.svg">](https://pypi.org/project/gym-mapf/)


# gym-mapf

Multi Agent Path Finding openAI gym environment.


Installation
------------
```pip install gym-mapf```


